.BG
.FN mda
.TL
Mixture Discriminant Analysis
.CS
mda(formula, data, subclasses, sub.df, tot.df, dimension, eps, iter, weights, method, keep.fitted, trace, ...)
.AG formula
of the form `y~x' it describes the response and the predictors. The
formula can be more complicated, such as `y~log(x)+z' etc (type
`?formula' for more details). The response should be a factor or
category representing the response variable, or any
vector that can be coerced to such (such as a logical
variable).
.AG data
data frame containing the variables in the formula (optional).
.AG subclasses
Number of subclasses per class -- default = 3. Can be a vector with a
number for each class.
.AG sub.df
If subclass centroid shrinking is performed, what is the effective
degrees of freedom of the centroids per class. Can be a scalar, in
which case the same number is used for each class, else a vector.
.AG tot.df
The total df for all the centroids can be specified rather than
separately per class.
.AG dimension
The dimension of the reduced model. If we know our final model will be
confined to a discriminant subspace (of the subclass centroids), we
can specify this in advance and have the EM algorithm operate in this subspace.
.AG eps
A numerical threshold for automatically truncating the dimension.
.AG iter
A limit on the total number of iterations -- default is 5.
.AG weights
NOT observation weights! This is a special weight structure, which for
each class assigns a weight (prior probability) to each of the
observations in that class of belonging to one of the subclasses. The
default is provided by a call to 
`mda.start(x, g, subclasses, trace, ...)' 
(by this time x and g are known). See the help for `mda.start'. 
Arguments for `mda.start()' can be provided via the `...' argument to
mda, and the `weights' argument need never be accessed. A previously
fit `mda' object can be supplied, in which case the final subclass
`responsibility' weights are used for `weights'. This allows the
iterations from a previous fit to be continued.
.AG method
regression method used in optimal scaling. Default is linear regression
via the function `polyreg', resulting in the usual mixture model.
Other possibilities are `mars' and `bruto'. For penalized mixture discriminant
models `gen.ridge' is appropriate.
.AG keep.fitted
a logical variable, which determines whether the (sometimes large) component
`"fitted.values"' of the `"fit"' component of the returned `mda' object should
be kept. The default is `TRUE' if `n * dimension < 1000' 
.AG trace
if TRUE, iteration information is printed. Note that the deviance
reported is for the posterior class likelihood, and not the full
likelihood, which is used to drive the EM algorithm under mda. In
general the latter is not available.
.AG ...
additional arguments to `mda.start()' and to `method()'.
.RT
An object of class `c("mda","fda")'. The most useful extractor is
`predict', which can make many types of predictions from this
object. It can also be plotted, and any functions useful for `"fda"'
objects will work here too, such as `confusion' and `coef'.
The object has the following components:
.RC percent.explained
the percent between-group variance explained by each dimension (relative to the total explained.) 
.RC values
optimal scaling regresssion sum-of-squares for each dimension (see reference).
.RC means
subclass means in the discriminant space. These are also scaled versions of the final theta's or class scores, and can be used in a subsequent call to `mda()' (this only makes sense if some columns of theta are omitted---see the references)
.RC theta.mod
(internal) a class scoring matrix which allows predict to work properly.
.RC dimension
dimension of discriminant space
.RC sub.prior
subclass membership priors, computed in the fit. No effort is
currently spent in trying to keep these above a threshold.
.RC prior
class proprotions for the training data
.RC fit
fit object returned by "method"
.RC call
the call that created this object (allowing it to be `update()'-able)
.RC confusion
confusion matrix when classifying the training data
.RC weights
These are the subclass membership probabilities for each member of the
training set; see the weights argument.
.RC assign.theta
a pointer list which identifies which elements of certian lists belong
to individual classes.
.RC deviance
The multinomial log-liklihood of the fit. Even though the full 
log-likelihood drives the iterations, we cannot in general compute it
because of the flexibility of the method() used.
The deviance can increase with the iterations, but generally does not.
.PP
The `method' functions are required to take arguments `x' and `y'
where both can be matrices, and should produce a matrix of
`fitted.values' the same size as `y'. They can take additional
arguments `weights' and should all have a `...' for safety sake.
Any arguments to method() can be passed on via the `...' argument
of `mda()'. The default method `polyreg()' has a `degree' argument
which allows polynomial regression of the required total degree. 
See the documentation for `predict.fda()' for further requirements
of `method'.
.PP
The function `mda.start()' creates the starting weights; it takes
additional arguments which can be passed in via the `...' argument to
`mda'. See the documentation for `mda.start'.
.PP
This software it is not well-tested, we would
like to hear of any bugs.
.PP
 Trevor Hastie and Robert Tibshirani
.SA
`predict.mda', `mars', `bruto', `polyreg', `gen.ridge', `softmax', `confusion'
.SH REFERENCE
"Flexible Disriminant Analysis by Optimal Scoring"  by Hastie,
Tibshirani and Buja, 1994, JASA, 1255-1270.
.br
"Penalized Discriminant Analysis" by Hastie, Buja and Tibshirani,
Annals of Statistics, 1995 (in press).
.br
"Discriminant Analysis by Gaussian Mixtures" by Hastie and Tibshirani,
1994, JRSS-B (in press).
.EX
> glass.mda <- mda(g ~ x, data = glass.train)
> glass.mda
Call:
mda(formula = g ~ x, data = glass.train)

Dimension: 9 

Percent Between-Group Variance Explained:
    v1    v2   v3    v4    v5    v6    v7    v8  v9 
 68.13 86.45 91.5 95.85 97.92 99.13 99.58 99.96 100

Degrees of Freedom (per dimension): 10 

Training Misclassification Error: 0.16854 ( N = 89 )

Deviance: 75.363 
> predict(glass.mda, type="post") # abbreviations are allowed
> confusion(glass.mda,glass.test)
    O VW WF WNF 
  O 9  0  0   4
 VW 0  3  4   3
 WF 0  4 27   5
WNF 2  1  9  25
attr(, "error"):
[1] 0.3333333

.KW classification
.WR 










